@@ -118,7 +118,7 @@ extern "C" Q_DECL_EXPORT int kdemain( int argc, char **argv )
     // and HTML previews need even KApplication :(
     putenv(strdup("SESSION_MANAGER="));
 
-    QCoreApplication app( argc, argv);
+    QGuiApplication app(argc, argv);
 #endif
 
 
@@ -711,7 +711,7 @@ bool ThumbnailProtocol::createSubThumbnail(QImage& thumbnail, const QString& fil
         int cacheSize = 0;
         QCryptographicHash md5(QCryptographicHash::Md5);
         md5.addData(QFile::encodeName(fileName.url()));
-        const QString thumbName = QFile::encodeName(md5.result()) + ".png";
+        const QString thumbName = QFile::encodeName(md5.result().toHex()) + ".png";
 
         if (m_thumbBasePath.isEmpty()) {
             m_thumbBasePath = QStandardPaths::writableLocation(QStandardPaths::GenericCacheLocation) + QLatin1String("/thumbnails/");
